@@ -25,12 +25,12 @@ from .utils import load_quantized_model
 from .compatibility import _upgrade_model_with_legacy_quantizers
 
 
-def quantize_model(model_path, wq, aq, iq):
+def quantize_model(model_path, wq, aq, iq, fold_BN):
     """Wrapper to quantize model"""
     model = load_quantized_model(model_path)
     if iq == -1:
         iq = wq
-    model_q = quantize(model, wq, aq, iq)
+    model_q = quantize(model, wq, aq, iq, fold_BN)
     # Extract base name
     base_name = os.path.splitext(model_path)[0]
     # Cross-platform path may contain alpha characters, /, \ and :
@@ -48,12 +48,12 @@ def quantize_model(model_path, wq, aq, iq):
     print(f"Model successfully quantized and saved as {out_path}.")
 
 
-def convert_model(model_path, scale, shift, is_image):
+def convert_model(model_path, input_scaling, is_image):
     """Wrapper to convert model"""
     base_name = os.path.splitext(model_path)[0]
     q_model = load_quantized_model(model_path)
     ak_model = convert(q_model,
-                       input_scaling=(scale, shift),
+                       input_scaling=input_scaling,
                        input_is_image=is_image)
     out_path = f"{base_name}.fbz"
     ak_model.save(out_path)
@@ -63,9 +63,16 @@ def convert_model(model_path, scale, shift, is_image):
 def main():
     """CNN2SNN command-line interface to quantize/convert/upgrade a model"""
     parser = argparse.ArgumentParser()
-    parser.add_argument("-m", "--model", default=None, help="The source model")
+    parent_parser = argparse.ArgumentParser(add_help=False)
+    parent_parser.add_argument("-m",
+                               "--model",
+                               type=str,
+                               required=True,
+                               help="The source model")
     sp = parser.add_subparsers(dest="action")
-    q_parser = sp.add_parser("quantize", help="Quantize a Keras model")
+    q_parser = sp.add_parser("quantize",
+                             parents=[parent_parser],
+                             help="Quantize a Keras model")
     q_parser.add_argument("-wq",
                           "--weight_quantization",
                           type=int,
@@ -82,24 +89,33 @@ def main():
                           default=-1,
                           help="The first layer weight quantization (same as" \
                           " weight_quantization if omitted)")
+    q_parser.add_argument("--no-fold-BN",
+                          dest="fold_BN",
+                          action='store_false',
+                          help="If specified, do not fold BatchNormalization "
+                          "layers before quantization")
     c_parser = sp.add_parser(
-        "convert", help="Convert a quantized Keras model to an akida model")
+        "convert",
+        parents=[parent_parser],
+        help="Convert a quantized Keras model to an Akida model")
     c_parser.add_argument("-sc",
                           "--scale",
                           type=int,
-                          default=1,
+                          default=None,
                           help="The scale factor applied on uint8 inputs.")
     c_parser.add_argument("-sh",
                           "--shift",
                           type=int,
-                          default=0,
+                          default=None,
                           help="The shift applied on uint8 inputs.")
     c_parser.add_argument("--no-image-input",
                           action='store_true',
                           default=False,
                           help="If inputs are not 8-bit images")
     u_parser = sp.add_parser(
-        "upgrade", help="Upgrade model to be compatible with cnn2snn>=1.8.10")
+        "upgrade",
+        parents=[parent_parser],
+        help="Upgrade model to be compatible with cnn2snn>=1.8.10")
     u_parser.add_argument("-o",
                           "--output",
                           type=str,
@@ -109,9 +125,13 @@ def main():
     args = parser.parse_args()
     if args.action == "quantize":
         quantize_model(args.model, args.weight_quantization,
-                       args.activ_quantization, args.input_weight_quantization)
+                       args.activ_quantization, args.input_weight_quantization,
+                       args.fold_BN)
     if args.action == "convert":
-        convert_model(args.model, args.scale, args.shift,
-                      not args.no_image_input)
+        if args.scale is None or args.shift is None:
+            input_scaling = None
+        else:
+            input_scaling = (args.scale, args.shift)
+        convert_model(args.model, input_scaling, not args.no_image_input)
     if args.action == "upgrade":
         _upgrade_model_with_legacy_quantizers(args.model, args.output)
