@@ -17,7 +17,7 @@
 """Functions to check model compatibility for CNN2SNN conversion.
 """
 
-from tensorflow.keras import Sequential, layers
+from keras import Sequential, layers
 
 from .transforms.sequential import (_raise_error_if_model_not_sequential,
                                     cut_model_to_sequentials,
@@ -283,7 +283,7 @@ def sequential_check_compatibility(model,
         elif isinstance(layer, layers.Reshape):
             _check_reshape_layer(layer)
         # Rescaling layer only supported as first layer of the first submodel
-        elif isinstance(layer, layers.experimental.preprocessing.Rescaling):
+        elif isinstance(layer, layers.Rescaling):
             _check_rescaling_compatibility(layer, i, input_is_image)
         # Activation/Softmax layer only supported after the last neural layer of
         # the last submodel
@@ -326,8 +326,7 @@ def _check_first_layer_with_image_input(model):
     """
 
     next_layer = 0
-    if isinstance(model.layers[next_layer],
-                  layers.experimental.preprocessing.Rescaling):
+    if isinstance(model.layers[next_layer], layers.Rescaling):
         next_layer += 1
 
     if (type(model.layers[next_layer])
