@@ -17,30 +17,30 @@
 """Parsing functions to generate an Akida model from a Keras model.
 """
 
-from tensorflow.keras import Sequential
-import tensorflow.keras.layers as layers
+from keras import Sequential
+import keras.layers as layers
 from akida import (Model, Convolutional, FullyConnected, SeparableConvolutional,
-                   InputData, InputConvolutional, ConvolutionMode, PoolingType,
-                   LayerType, Concat)
+                   InputData, InputConvolutional, Padding, PoolType, LayerType,
+                   Concat)
 from . import quantization_layers as qlayers
 from .transforms.sequential import _raise_error_if_model_not_sequential
 from .weights_ops import set_layer_variables
 
 
-def _get_convolution_mode(str_conv_mode):
-    if str_conv_mode == 'same':
-        return ConvolutionMode.Same
-    return ConvolutionMode.Valid
+def _get_padding(str_padding):
+    if str_padding == 'same':
+        return Padding.Same
+    return Padding.Valid
 
 
 def _parse_input_data(layer, params):
     if len(layer.input_shape) == 2:
-        params["input_height"] = params["input_width"] = 1
-        params["input_channels"] = int(layer.input_shape[1])
+        params["input_shape"] = (1, 1, int(layer.input_shape[1]))
+
     else:
-        params["input_height"] = int(layer.input_shape[1])
-        params["input_width"] = int(layer.input_shape[2])
-        params["input_channels"] = int(layer.input_shape[3])
+        params["input_shape"] = (int(layer.input_shape[2]),
+                                 int(layer.input_shape[1]),
+                                 int(layer.input_shape[3]))
     params['name'] = layer.name + "_input"
 
 
@@ -49,16 +49,14 @@ def _parse_input_conv(layer, params, input_shift):
         raise TypeError(f"First layer {layer.name} must be QuantizedConv2D "
                         "when input_is_image=True. Received layer of type "
                         f"{layer.__class__.__name__}")
-    params["input_height"] = int(layer.input_shape[1])
-    params["input_width"] = int(layer.input_shape[2])
-    params["convolution_mode"] = _get_convolution_mode(layer.padding)
-    params["kernel_height"] = layer.kernel_size[0]
-    params["kernel_width"] = layer.kernel_size[1]
-    params["num_neurons"] = int(layer.kernel.shape[3])
+    params["input_shape"] = (int(layer.input_shape[2]),
+                             int(layer.input_shape[1]),
+                             int(layer.input_shape[3]))
+    params["padding"] = _get_padding(layer.padding)
+    params["kernel_size"] = (layer.kernel_size[1], layer.kernel_size[0])
+    params["filters"] = int(layer.kernel.shape[3])
     params["weights_bits"] = layer.quantizer.bitwidth
-    params["input_channels"] = int(layer.input_shape[3])
-    params["stride_x"] = layer.strides[1]
-    params["stride_y"] = layer.strides[0]
+    params["kernel_stride"] = (layer.strides[1], layer.strides[0])
     params["name"] = layer.name
     params["padding_value"] = int(input_shift)
 
@@ -67,13 +65,11 @@ def _parse_conv(layer, params):
     if not isinstance(layer, qlayers.QuantizedConv2D):
         raise TypeError(f"Layer {layer.name} was expected to be "
                         "QuantizedConv2D")
-    params["convolution_mode"] = _get_convolution_mode(layer.padding)
-    params["kernel_height"] = layer.kernel_size[0]
-    params["kernel_width"] = layer.kernel_size[1]
-    params["num_neurons"] = int(layer.kernel.shape[3])
+    params["padding"] = _get_padding(layer.padding)
+    params["kernel_size"] = (layer.kernel_size[1], layer.kernel_size[0])
+    params["filters"] = int(layer.kernel.shape[3])
     params["weights_bits"] = layer.quantizer.bitwidth
-    params["stride_x"] = layer.strides[1]
-    params["stride_y"] = layer.strides[0]
+    params["kernel_stride"] = (layer.strides[1], layer.strides[0])
     params["name"] = layer.name
 
 
@@ -84,14 +80,12 @@ def _parse_separable_conv(layer, params):
     if layer.quantizer_dw.bitwidth != layer.quantizer.bitwidth:
         raise ValueError(f"Quantized layer {layer.name} must have the same "
                          f"bitwidth for depthwise and pointwise quantizers.")
-    params["convolution_mode"] = _get_convolution_mode(layer.padding)
-    params["kernel_height"] = layer.kernel_size[0]
-    params["kernel_width"] = layer.kernel_size[1]
-    # num neurons is set to the number of filters of the depthwise
-    params["num_neurons"] = int(layer.pointwise_kernel.shape[3])
+    params["padding"] = _get_padding(layer.padding)
+    params["kernel_size"] = (layer.kernel_size[1], layer.kernel_size[0])
+    # filters is set to the number of filters of the depthwise
+    params["filters"] = int(layer.pointwise_kernel.shape[3])
     params["weights_bits"] = layer.quantizer.bitwidth
-    params["stride_x"] = layer.strides[1]
-    params["stride_y"] = layer.strides[0]
+    params["kernel_stride"] = (layer.strides[1], layer.strides[0])
     params["name"] = layer.name
 
 
@@ -99,7 +93,7 @@ def _parse_dense(layer, params):
     if not isinstance(layer, qlayers.QuantizedDense):
         raise TypeError(f"Layer {layer.name} was expected to be "
                         "QuantizedDense")
-    params["num_neurons"] = layer.units
+    params["units"] = layer.units
     params["weights_bits"] = layer.quantizer.bitwidth
     params["name"] = layer.name
 
@@ -107,18 +101,16 @@ def _parse_dense(layer, params):
 def _parse_max_pooling(layer, params):
     if not isinstance(layer, layers.MaxPooling2D):
         raise TypeError(f"Layer {layer.name} was expected to be MaxPooling2D")
-    params["pooling_type"] = PoolingType.Max
-    params["pooling_height"] = layer.pool_size[0]
-    params["pooling_width"] = layer.pool_size[1]
-    params["pooling_stride_y"] = layer.strides[0]
-    params["pooling_stride_x"] = layer.strides[1]
+    params["pool_type"] = PoolType.Max
+    params["pool_size"] = (layer.pool_size[1], layer.pool_size[0])
+    params["pool_stride"] = (layer.strides[1], layer.strides[0])
 
 
 def _parse_global_average_pooling(layer, params):
     if not isinstance(layer, layers.GlobalAveragePooling2D):
         raise TypeError(f"Layer {layer.name} was expected to be "
                         "GlobalAveragePooling2D")
-    params["pooling_type"] = PoolingType.Average
+    params["pool_type"] = PoolType.Average
 
 
 def _create_akida_layer(layer_type, params):
@@ -196,8 +188,8 @@ def generate_model(model, input_scaling, input_is_image):
             concat_input_layers = [output_layers_ak[l] for l in inbound_layers]
             _check_concat_input_bitwidths(layer, concat_input_layers)
             # Add Concat layer to the Akida model
-            act_bitwidth = concat_input_layers[0].parameters.threshold_fire_bits
-            layer_ak = Concat(name=layer.name, threshold_fire_bits=act_bitwidth)
+            act_bits = concat_input_layers[0].parameters.act_bits
+            layer_ak = Concat(name=layer.name, act_bits=act_bits)
             model_ak.add(layer_ak, concat_input_layers)
             output_layers_ak[layer] = layer_ak
         elif isinstance(layer, Sequential):
@@ -292,7 +284,7 @@ def sequential_convert_to_akida_layers(model,
         elif isinstance(layer, qlayers.QuantizedActivation):
             layer_activation = layer
             _check_activation_bitwidth(layer_activation)
-            params['threshold_fire_bits'] = layer_activation.bitwidth
+            params['act_bits'] = layer_activation.bitwidth
 
             # An activation layer ends a block for an Akida layer : create
             # the corresponding Akida layer and set weights/thresholds
@@ -314,7 +306,7 @@ def sequential_convert_to_akida_layers(model,
 
     # Handle last layer if there is no activation
     if layer_neural is not None:
-        params["activations_enabled"] = False
+        params["activation"] = False
         layer_ak = _create_akida_layer(layer_ak_type, params)
         model_ak.add(layer_ak, previous_layer_ak)
         set_layer_variables(layer_ak, input_scaling, layer_neural,
@@ -367,8 +359,7 @@ def _handle_input_conv_layer(model, input_scaling):
 
     next_neural_layer_id = 0
     # If next layer is Rescaling layer, skip it
-    if isinstance(model.layers[next_neural_layer_id],
-                  layers.experimental.preprocessing.Rescaling):
+    if isinstance(model.layers[next_neural_layer_id], layers.Rescaling):
         next_neural_layer_id += 1
 
     params = {}
@@ -396,9 +387,7 @@ def _check_concat_input_bitwidths(layer, concat_input_layers):
         concat_input_layers (list): Akida inbound layers of the Concat layer.
     """
 
-    output_bitwidths = [
-        l.parameters.threshold_fire_bits for l in concat_input_layers
-    ]
+    output_bitwidths = [l.parameters.act_bits for l in concat_input_layers]
 
     if len(set(output_bitwidths)) > 1:
         raise RuntimeError(
@@ -408,9 +397,9 @@ def _check_concat_input_bitwidths(layer, concat_input_layers):
 
 
 def _check_weight_bitwidth(bitwidth, layer_name):
-    """Checks that weight bitwidth is supported by Akida: 1, 2, 4 or 8 bits.
+    """Checks that weight bitwidth is supported by Akida: 2, 4 or 8 bits.
     """
 
-    if bitwidth not in (1, 2, 4, 8):
-        raise ValueError("Weight bitwidth must be in (1, 2, 4, 8). Receives "
+    if bitwidth not in (2, 4, 8):
+        raise ValueError("Weight bitwidth must be in (2, 4, 8). Receives "
                          f"bitwidth {bitwidth} in layer '{layer_name}'.")
