@@ -23,10 +23,10 @@ Sequential models.
 
 import numpy as np
 import tensorflow as tf
-from tensorflow.keras import Model, Sequential, Input
-from tensorflow.keras.layers import (Conv2D, SeparableConv2D, Dense, MaxPool2D,
-                                     GlobalAvgPool2D, ReLU, BatchNormalization,
-                                     Dropout, Concatenate, InputLayer)
+from keras import Model, Sequential, Input
+from keras.layers import (Conv2D, SeparableConv2D, Dense, MaxPool2D,
+                          GlobalAvgPool2D, ReLU, BatchNormalization, Dropout,
+                          Concatenate, InputLayer)
 
 from ..cnn2snn_objects import cnn2snn_objects
 from ..quantization_ops import ScaleFactorQuantizer
